// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: object_detection/protos/hyperparams.proto

#include "object_detection/protos/hyperparams.pb.h"

#include <algorithm>

#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/extension_set.h>
#include <google/protobuf/wire_format_lite.h>
#include <google/protobuf/descriptor.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/reflection_ops.h>
#include <google/protobuf/wire_format.h>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>

PROTOBUF_PRAGMA_INIT_SEG

namespace _pb = ::PROTOBUF_NAMESPACE_ID;
namespace _pbi = _pb::internal;

namespace object_detection {
namespace protos {
PROTOBUF_CONSTEXPR Hyperparams::Hyperparams(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.regularizer_)*/nullptr
  , /*decltype(_impl_.initializer_)*/nullptr
  , /*decltype(_impl_.regularize_depthwise_)*/false
  , /*decltype(_impl_.op_)*/1
  , /*decltype(_impl_.activation_)*/1
  , /*decltype(_impl_.normalizer_oneof_)*/{}
  , /*decltype(_impl_._oneof_case_)*/{}} {}
struct HyperparamsDefaultTypeInternal {
  PROTOBUF_CONSTEXPR HyperparamsDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~HyperparamsDefaultTypeInternal() {}
  union {
    Hyperparams _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 HyperparamsDefaultTypeInternal _Hyperparams_default_instance_;
PROTOBUF_CONSTEXPR Regularizer::Regularizer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_.regularizer_oneof_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_._oneof_case_)*/{}} {}
struct RegularizerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR RegularizerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~RegularizerDefaultTypeInternal() {}
  union {
    Regularizer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 RegularizerDefaultTypeInternal _Regularizer_default_instance_;
PROTOBUF_CONSTEXPR L1Regularizer::L1Regularizer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.weight_)*/1} {}
struct L1RegularizerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR L1RegularizerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~L1RegularizerDefaultTypeInternal() {}
  union {
    L1Regularizer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 L1RegularizerDefaultTypeInternal _L1Regularizer_default_instance_;
PROTOBUF_CONSTEXPR L2Regularizer::L2Regularizer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.weight_)*/1} {}
struct L2RegularizerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR L2RegularizerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~L2RegularizerDefaultTypeInternal() {}
  union {
    L2Regularizer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 L2RegularizerDefaultTypeInternal _L2Regularizer_default_instance_;
PROTOBUF_CONSTEXPR Initializer::Initializer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_.initializer_oneof_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_._oneof_case_)*/{}} {}
struct InitializerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR InitializerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~InitializerDefaultTypeInternal() {}
  union {
    Initializer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 InitializerDefaultTypeInternal _Initializer_default_instance_;
PROTOBUF_CONSTEXPR TruncatedNormalInitializer::TruncatedNormalInitializer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.mean_)*/0
  , /*decltype(_impl_.stddev_)*/1} {}
struct TruncatedNormalInitializerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR TruncatedNormalInitializerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~TruncatedNormalInitializerDefaultTypeInternal() {}
  union {
    TruncatedNormalInitializer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 TruncatedNormalInitializerDefaultTypeInternal _TruncatedNormalInitializer_default_instance_;
PROTOBUF_CONSTEXPR VarianceScalingInitializer::VarianceScalingInitializer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.uniform_)*/false
  , /*decltype(_impl_.mode_)*/0
  , /*decltype(_impl_.factor_)*/2} {}
struct VarianceScalingInitializerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR VarianceScalingInitializerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~VarianceScalingInitializerDefaultTypeInternal() {}
  union {
    VarianceScalingInitializer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 VarianceScalingInitializerDefaultTypeInternal _VarianceScalingInitializer_default_instance_;
PROTOBUF_CONSTEXPR RandomNormalInitializer::RandomNormalInitializer(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.mean_)*/0
  , /*decltype(_impl_.stddev_)*/1} {}
struct RandomNormalInitializerDefaultTypeInternal {
  PROTOBUF_CONSTEXPR RandomNormalInitializerDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~RandomNormalInitializerDefaultTypeInternal() {}
  union {
    RandomNormalInitializer _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 RandomNormalInitializerDefaultTypeInternal _RandomNormalInitializer_default_instance_;
PROTOBUF_CONSTEXPR BatchNorm::BatchNorm(
    ::_pbi::ConstantInitialized): _impl_{
    /*decltype(_impl_._has_bits_)*/{}
  , /*decltype(_impl_._cached_size_)*/{}
  , /*decltype(_impl_.scale_)*/false
  , /*decltype(_impl_.epsilon_)*/0.001f
  , /*decltype(_impl_.decay_)*/0.999f
  , /*decltype(_impl_.center_)*/true
  , /*decltype(_impl_.train_)*/true} {}
struct BatchNormDefaultTypeInternal {
  PROTOBUF_CONSTEXPR BatchNormDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~BatchNormDefaultTypeInternal() {}
  union {
    BatchNorm _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 BatchNormDefaultTypeInternal _BatchNorm_default_instance_;
PROTOBUF_CONSTEXPR GroupNorm::GroupNorm(
    ::_pbi::ConstantInitialized) {}
struct GroupNormDefaultTypeInternal {
  PROTOBUF_CONSTEXPR GroupNormDefaultTypeInternal()
      : _instance(::_pbi::ConstantInitialized{}) {}
  ~GroupNormDefaultTypeInternal() {}
  union {
    GroupNorm _instance;
  };
};
PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 GroupNormDefaultTypeInternal _GroupNorm_default_instance_;
}  // namespace protos
}  // namespace object_detection
static ::_pb::Metadata file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[10];
static const ::_pb::EnumDescriptor* file_level_enum_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto[3];
static constexpr ::_pb::ServiceDescriptor const** file_level_service_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto = nullptr;

const uint32_t TableStruct_object_5fdetection_2fprotos_2fhyperparams_2eproto::offsets[] PROTOBUF_SECTION_VARIABLE(protodesc_cold) = {
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _internal_metadata_),
  ~0u,  // no _extensions_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_._oneof_case_[0]),
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.op_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.regularizer_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.initializer_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.activation_),
  ::_pbi::kInvalidFieldOffsetTag,
  ::_pbi::kInvalidFieldOffsetTag,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.regularize_depthwise_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Hyperparams, _impl_.normalizer_oneof_),
  3,
  0,
  1,
  4,
  ~0u,
  ~0u,
  2,
  ~0u,  // no _has_bits_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Regularizer, _internal_metadata_),
  ~0u,  // no _extensions_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Regularizer, _impl_._oneof_case_[0]),
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  ::_pbi::kInvalidFieldOffsetTag,
  ::_pbi::kInvalidFieldOffsetTag,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Regularizer, _impl_.regularizer_oneof_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L1Regularizer, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L1Regularizer, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L1Regularizer, _impl_.weight_),
  0,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L2Regularizer, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L2Regularizer, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::L2Regularizer, _impl_.weight_),
  0,
  ~0u,  // no _has_bits_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Initializer, _internal_metadata_),
  ~0u,  // no _extensions_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Initializer, _impl_._oneof_case_[0]),
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  ::_pbi::kInvalidFieldOffsetTag,
  ::_pbi::kInvalidFieldOffsetTag,
  ::_pbi::kInvalidFieldOffsetTag,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::Initializer, _impl_.initializer_oneof_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::TruncatedNormalInitializer, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::TruncatedNormalInitializer, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::TruncatedNormalInitializer, _impl_.mean_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::TruncatedNormalInitializer, _impl_.stddev_),
  0,
  1,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::VarianceScalingInitializer, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::VarianceScalingInitializer, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::VarianceScalingInitializer, _impl_.factor_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::VarianceScalingInitializer, _impl_.uniform_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::VarianceScalingInitializer, _impl_.mode_),
  2,
  0,
  1,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::RandomNormalInitializer, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::RandomNormalInitializer, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::RandomNormalInitializer, _impl_.mean_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::RandomNormalInitializer, _impl_.stddev_),
  0,
  1,
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_._has_bits_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_.decay_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_.center_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_.scale_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_.epsilon_),
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::BatchNorm, _impl_.train_),
  2,
  3,
  0,
  1,
  4,
  ~0u,  // no _has_bits_
  PROTOBUF_FIELD_OFFSET(::object_detection::protos::GroupNorm, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  ~0u,  // no _inlined_string_donated_
};
static const ::_pbi::MigrationSchema schemas[] PROTOBUF_SECTION_VARIABLE(protodesc_cold) = {
  { 0, 14, -1, sizeof(::object_detection::protos::Hyperparams)},
  { 21, -1, -1, sizeof(::object_detection::protos::Regularizer)},
  { 30, 37, -1, sizeof(::object_detection::protos::L1Regularizer)},
  { 38, 45, -1, sizeof(::object_detection::protos::L2Regularizer)},
  { 46, -1, -1, sizeof(::object_detection::protos::Initializer)},
  { 56, 64, -1, sizeof(::object_detection::protos::TruncatedNormalInitializer)},
  { 66, 75, -1, sizeof(::object_detection::protos::VarianceScalingInitializer)},
  { 78, 86, -1, sizeof(::object_detection::protos::RandomNormalInitializer)},
  { 88, 99, -1, sizeof(::object_detection::protos::BatchNorm)},
  { 104, -1, -1, sizeof(::object_detection::protos::GroupNorm)},
};

static const ::_pb::Message* const file_default_instances[] = {
  &::object_detection::protos::_Hyperparams_default_instance_._instance,
  &::object_detection::protos::_Regularizer_default_instance_._instance,
  &::object_detection::protos::_L1Regularizer_default_instance_._instance,
  &::object_detection::protos::_L2Regularizer_default_instance_._instance,
  &::object_detection::protos::_Initializer_default_instance_._instance,
  &::object_detection::protos::_TruncatedNormalInitializer_default_instance_._instance,
  &::object_detection::protos::_VarianceScalingInitializer_default_instance_._instance,
  &::object_detection::protos::_RandomNormalInitializer_default_instance_._instance,
  &::object_detection::protos::_BatchNorm_default_instance_._instance,
  &::object_detection::protos::_GroupNorm_default_instance_._instance,
};

const char descriptor_table_protodef_object_5fdetection_2fprotos_2fhyperparams_2eproto[] PROTOBUF_SECTION_VARIABLE(protodesc_cold) =
  "\n)object_detection/protos/hyperparams.pr"
  "oto\022\027object_detection.protos\"\374\003\n\013Hyperpa"
  "rams\0229\n\002op\030\001 \001(\0162\'.object_detection.prot"
  "os.Hyperparams.Op:\004CONV\0229\n\013regularizer\030\002"
  " \001(\0132$.object_detection.protos.Regulariz"
  "er\0229\n\013initializer\030\003 \001(\0132$.object_detecti"
  "on.protos.Initializer\022I\n\nactivation\030\004 \001("
  "\0162/.object_detection.protos.Hyperparams."
  "Activation:\004RELU\0228\n\nbatch_norm\030\005 \001(\0132\".o"
  "bject_detection.protos.BatchNormH\000\0228\n\ngr"
  "oup_norm\030\007 \001(\0132\".object_detection.protos"
  ".GroupNormH\000\022#\n\024regularize_depthwise\030\006 \001"
  "(\010:\005false\"\026\n\002Op\022\010\n\004CONV\020\001\022\006\n\002FC\020\002\",\n\nAct"
  "ivation\022\010\n\004NONE\020\000\022\010\n\004RELU\020\001\022\n\n\006RELU_6\020\002B"
  "\022\n\020normalizer_oneof\"\246\001\n\013Regularizer\022@\n\016l"
  "1_regularizer\030\001 \001(\0132&.object_detection.p"
  "rotos.L1RegularizerH\000\022@\n\016l2_regularizer\030"
  "\002 \001(\0132&.object_detection.protos.L2Regula"
  "rizerH\000B\023\n\021regularizer_oneof\"\"\n\rL1Regula"
  "rizer\022\021\n\006weight\030\001 \001(\002:\0011\"\"\n\rL2Regularize"
  "r\022\021\n\006weight\030\001 \001(\002:\0011\"\263\002\n\013Initializer\022[\n\034"
  "truncated_normal_initializer\030\001 \001(\01323.obj"
  "ect_detection.protos.TruncatedNormalInit"
  "ializerH\000\022[\n\034variance_scaling_initialize"
  "r\030\002 \001(\01323.object_detection.protos.Varian"
  "ceScalingInitializerH\000\022U\n\031random_normal_"
  "initializer\030\003 \001(\01320.object_detection.pro"
  "tos.RandomNormalInitializerH\000B\023\n\021initial"
  "izer_oneof\"@\n\032TruncatedNormalInitializer"
  "\022\017\n\004mean\030\001 \001(\002:\0010\022\021\n\006stddev\030\002 \001(\002:\0011\"\305\001\n"
  "\032VarianceScalingInitializer\022\021\n\006factor\030\001 "
  "\001(\002:\0012\022\026\n\007uniform\030\002 \001(\010:\005false\022N\n\004mode\030\003"
  " \001(\01628.object_detection.protos.VarianceS"
  "calingInitializer.Mode:\006FAN_IN\",\n\004Mode\022\n"
  "\n\006FAN_IN\020\000\022\013\n\007FAN_OUT\020\001\022\013\n\007FAN_AVG\020\002\"=\n\027"
  "RandomNormalInitializer\022\017\n\004mean\030\001 \001(\002:\0010"
  "\022\021\n\006stddev\030\002 \001(\002:\0011\"z\n\tBatchNorm\022\024\n\005deca"
  "y\030\001 \001(\002:\0050.999\022\024\n\006center\030\002 \001(\010:\004true\022\024\n\005"
  "scale\030\003 \001(\010:\005false\022\026\n\007epsilon\030\004 \001(\002:\0050.0"
  "01\022\023\n\005train\030\005 \001(\010:\004true\"\013\n\tGroupNorm"
  ;
static ::_pbi::once_flag descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once;
const ::_pbi::DescriptorTable descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto = {
    false, false, 1596, descriptor_table_protodef_object_5fdetection_2fprotos_2fhyperparams_2eproto,
    "object_detection/protos/hyperparams.proto",
    &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once, nullptr, 0, 10,
    schemas, file_default_instances, TableStruct_object_5fdetection_2fprotos_2fhyperparams_2eproto::offsets,
    file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto, file_level_enum_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto,
    file_level_service_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto,
};
PROTOBUF_ATTRIBUTE_WEAK const ::_pbi::DescriptorTable* descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter() {
  return &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto;
}

// Force running AddDescriptors() at dynamic initialization time.
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::_pbi::AddDescriptorsRunner dynamic_init_dummy_object_5fdetection_2fprotos_2fhyperparams_2eproto(&descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto);
namespace object_detection {
namespace protos {
const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Hyperparams_Op_descriptor() {
  ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto);
  return file_level_enum_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto[0];
}
bool Hyperparams_Op_IsValid(int value) {
  switch (value) {
    case 1:
    case 2:
      return true;
    default:
      return false;
  }
}

#if (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))
constexpr Hyperparams_Op Hyperparams::CONV;
constexpr Hyperparams_Op Hyperparams::FC;
constexpr Hyperparams_Op Hyperparams::Op_MIN;
constexpr Hyperparams_Op Hyperparams::Op_MAX;
constexpr int Hyperparams::Op_ARRAYSIZE;
#endif  // (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))
const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Hyperparams_Activation_descriptor() {
  ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto);
  return file_level_enum_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto[1];
}
bool Hyperparams_Activation_IsValid(int value) {
  switch (value) {
    case 0:
    case 1:
    case 2:
      return true;
    default:
      return false;
  }
}

#if (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))
constexpr Hyperparams_Activation Hyperparams::NONE;
constexpr Hyperparams_Activation Hyperparams::RELU;
constexpr Hyperparams_Activation Hyperparams::RELU_6;
constexpr Hyperparams_Activation Hyperparams::Activation_MIN;
constexpr Hyperparams_Activation Hyperparams::Activation_MAX;
constexpr int Hyperparams::Activation_ARRAYSIZE;
#endif  // (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))
const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* VarianceScalingInitializer_Mode_descriptor() {
  ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto);
  return file_level_enum_descriptors_object_5fdetection_2fprotos_2fhyperparams_2eproto[2];
}
bool VarianceScalingInitializer_Mode_IsValid(int value) {
  switch (value) {
    case 0:
    case 1:
    case 2:
      return true;
    default:
      return false;
  }
}

#if (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))
constexpr VarianceScalingInitializer_Mode VarianceScalingInitializer::FAN_IN;
constexpr VarianceScalingInitializer_Mode VarianceScalingInitializer::FAN_OUT;
constexpr VarianceScalingInitializer_Mode VarianceScalingInitializer::FAN_AVG;
constexpr VarianceScalingInitializer_Mode VarianceScalingInitializer::Mode_MIN;
constexpr VarianceScalingInitializer_Mode VarianceScalingInitializer::Mode_MAX;
constexpr int VarianceScalingInitializer::Mode_ARRAYSIZE;
#endif  // (__cplusplus < 201703) && (!defined(_MSC_VER) || (_MSC_VER >= 1900 && _MSC_VER < 1912))

// ===================================================================

class Hyperparams::_Internal {
 public:
  using HasBits = decltype(std::declval<Hyperparams>()._impl_._has_bits_);
  static void set_has_op(HasBits* has_bits) {
    (*has_bits)[0] |= 8u;
  }
  static const ::object_detection::protos::Regularizer& regularizer(const Hyperparams* msg);
  static void set_has_regularizer(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
  static const ::object_detection::protos::Initializer& initializer(const Hyperparams* msg);
  static void set_has_initializer(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
  static void set_has_activation(HasBits* has_bits) {
    (*has_bits)[0] |= 16u;
  }
  static const ::object_detection::protos::BatchNorm& batch_norm(const Hyperparams* msg);
  static const ::object_detection::protos::GroupNorm& group_norm(const Hyperparams* msg);
  static void set_has_regularize_depthwise(HasBits* has_bits) {
    (*has_bits)[0] |= 4u;
  }
};

const ::object_detection::protos::Regularizer&
Hyperparams::_Internal::regularizer(const Hyperparams* msg) {
  return *msg->_impl_.regularizer_;
}
const ::object_detection::protos::Initializer&
Hyperparams::_Internal::initializer(const Hyperparams* msg) {
  return *msg->_impl_.initializer_;
}
const ::object_detection::protos::BatchNorm&
Hyperparams::_Internal::batch_norm(const Hyperparams* msg) {
  return *msg->_impl_.normalizer_oneof_.batch_norm_;
}
const ::object_detection::protos::GroupNorm&
Hyperparams::_Internal::group_norm(const Hyperparams* msg) {
  return *msg->_impl_.normalizer_oneof_.group_norm_;
}
void Hyperparams::set_allocated_batch_norm(::object_detection::protos::BatchNorm* batch_norm) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_normalizer_oneof();
  if (batch_norm) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(batch_norm);
    if (message_arena != submessage_arena) {
      batch_norm = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, batch_norm, submessage_arena);
    }
    set_has_batch_norm();
    _impl_.normalizer_oneof_.batch_norm_ = batch_norm;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Hyperparams.batch_norm)
}
void Hyperparams::set_allocated_group_norm(::object_detection::protos::GroupNorm* group_norm) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_normalizer_oneof();
  if (group_norm) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(group_norm);
    if (message_arena != submessage_arena) {
      group_norm = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, group_norm, submessage_arena);
    }
    set_has_group_norm();
    _impl_.normalizer_oneof_.group_norm_ = group_norm;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Hyperparams.group_norm)
}
Hyperparams::Hyperparams(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.Hyperparams)
}
Hyperparams::Hyperparams(const Hyperparams& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  Hyperparams* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.regularizer_){nullptr}
    , decltype(_impl_.initializer_){nullptr}
    , decltype(_impl_.regularize_depthwise_){}
    , decltype(_impl_.op_){}
    , decltype(_impl_.activation_){}
    , decltype(_impl_.normalizer_oneof_){}
    , /*decltype(_impl_._oneof_case_)*/{}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  if (from._internal_has_regularizer()) {
    _this->_impl_.regularizer_ = new ::object_detection::protos::Regularizer(*from._impl_.regularizer_);
  }
  if (from._internal_has_initializer()) {
    _this->_impl_.initializer_ = new ::object_detection::protos::Initializer(*from._impl_.initializer_);
  }
  ::memcpy(&_impl_.regularize_depthwise_, &from._impl_.regularize_depthwise_,
    static_cast<size_t>(reinterpret_cast<char*>(&_impl_.activation_) -
    reinterpret_cast<char*>(&_impl_.regularize_depthwise_)) + sizeof(_impl_.activation_));
  clear_has_normalizer_oneof();
  switch (from.normalizer_oneof_case()) {
    case kBatchNorm: {
      _this->_internal_mutable_batch_norm()->::object_detection::protos::BatchNorm::MergeFrom(
          from._internal_batch_norm());
      break;
    }
    case kGroupNorm: {
      _this->_internal_mutable_group_norm()->::object_detection::protos::GroupNorm::MergeFrom(
          from._internal_group_norm());
      break;
    }
    case NORMALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.Hyperparams)
}

inline void Hyperparams::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.regularizer_){nullptr}
    , decltype(_impl_.initializer_){nullptr}
    , decltype(_impl_.regularize_depthwise_){false}
    , decltype(_impl_.op_){1}
    , decltype(_impl_.activation_){1}
    , decltype(_impl_.normalizer_oneof_){}
    , /*decltype(_impl_._oneof_case_)*/{}
  };
  clear_has_normalizer_oneof();
}

Hyperparams::~Hyperparams() {
  // @@protoc_insertion_point(destructor:object_detection.protos.Hyperparams)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void Hyperparams::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
  if (this != internal_default_instance()) delete _impl_.regularizer_;
  if (this != internal_default_instance()) delete _impl_.initializer_;
  if (has_normalizer_oneof()) {
    clear_normalizer_oneof();
  }
}

void Hyperparams::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void Hyperparams::clear_normalizer_oneof() {
// @@protoc_insertion_point(one_of_clear_start:object_detection.protos.Hyperparams)
  switch (normalizer_oneof_case()) {
    case kBatchNorm: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.normalizer_oneof_.batch_norm_;
      }
      break;
    }
    case kGroupNorm: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.normalizer_oneof_.group_norm_;
      }
      break;
    }
    case NORMALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = NORMALIZER_ONEOF_NOT_SET;
}


void Hyperparams::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.Hyperparams)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    if (cached_has_bits & 0x00000001u) {
      GOOGLE_DCHECK(_impl_.regularizer_ != nullptr);
      _impl_.regularizer_->Clear();
    }
    if (cached_has_bits & 0x00000002u) {
      GOOGLE_DCHECK(_impl_.initializer_ != nullptr);
      _impl_.initializer_->Clear();
    }
  }
  if (cached_has_bits & 0x0000001cu) {
    _impl_.regularize_depthwise_ = false;
    _impl_.op_ = 1;
    _impl_.activation_ = 1;
  }
  clear_normalizer_oneof();
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* Hyperparams::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional .object_detection.protos.Hyperparams.Op op = 1 [default = CONV];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 8)) {
          uint64_t val = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
          if (PROTOBUF_PREDICT_TRUE(::object_detection::protos::Hyperparams_Op_IsValid(val))) {
            _internal_set_op(static_cast<::object_detection::protos::Hyperparams_Op>(val));
          } else {
            ::PROTOBUF_NAMESPACE_ID::internal::WriteVarint(1, val, mutable_unknown_fields());
          }
        } else
          goto handle_unusual;
        continue;
      // optional .object_detection.protos.Regularizer regularizer = 2;
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 18)) {
          ptr = ctx->ParseMessage(_internal_mutable_regularizer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional .object_detection.protos.Initializer initializer = 3;
      case 3:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 26)) {
          ptr = ctx->ParseMessage(_internal_mutable_initializer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional .object_detection.protos.Hyperparams.Activation activation = 4 [default = RELU];
      case 4:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 32)) {
          uint64_t val = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
          if (PROTOBUF_PREDICT_TRUE(::object_detection::protos::Hyperparams_Activation_IsValid(val))) {
            _internal_set_activation(static_cast<::object_detection::protos::Hyperparams_Activation>(val));
          } else {
            ::PROTOBUF_NAMESPACE_ID::internal::WriteVarint(4, val, mutable_unknown_fields());
          }
        } else
          goto handle_unusual;
        continue;
      // .object_detection.protos.BatchNorm batch_norm = 5;
      case 5:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 42)) {
          ptr = ctx->ParseMessage(_internal_mutable_batch_norm(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional bool regularize_depthwise = 6 [default = false];
      case 6:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 48)) {
          _Internal::set_has_regularize_depthwise(&has_bits);
          _impl_.regularize_depthwise_ = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // .object_detection.protos.GroupNorm group_norm = 7;
      case 7:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 58)) {
          ptr = ctx->ParseMessage(_internal_mutable_group_norm(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* Hyperparams::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.Hyperparams)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional .object_detection.protos.Hyperparams.Op op = 1 [default = CONV];
  if (cached_has_bits & 0x00000008u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteEnumToArray(
      1, this->_internal_op(), target);
  }

  // optional .object_detection.protos.Regularizer regularizer = 2;
  if (cached_has_bits & 0x00000001u) {
    target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
      InternalWriteMessage(2, _Internal::regularizer(this),
        _Internal::regularizer(this).GetCachedSize(), target, stream);
  }

  // optional .object_detection.protos.Initializer initializer = 3;
  if (cached_has_bits & 0x00000002u) {
    target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
      InternalWriteMessage(3, _Internal::initializer(this),
        _Internal::initializer(this).GetCachedSize(), target, stream);
  }

  // optional .object_detection.protos.Hyperparams.Activation activation = 4 [default = RELU];
  if (cached_has_bits & 0x00000010u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteEnumToArray(
      4, this->_internal_activation(), target);
  }

  // .object_detection.protos.BatchNorm batch_norm = 5;
  if (_internal_has_batch_norm()) {
    target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
      InternalWriteMessage(5, _Internal::batch_norm(this),
        _Internal::batch_norm(this).GetCachedSize(), target, stream);
  }

  // optional bool regularize_depthwise = 6 [default = false];
  if (cached_has_bits & 0x00000004u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(6, this->_internal_regularize_depthwise(), target);
  }

  // .object_detection.protos.GroupNorm group_norm = 7;
  if (_internal_has_group_norm()) {
    target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
      InternalWriteMessage(7, _Internal::group_norm(this),
        _Internal::group_norm(this).GetCachedSize(), target, stream);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.Hyperparams)
  return target;
}

size_t Hyperparams::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.Hyperparams)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x0000001fu) {
    // optional .object_detection.protos.Regularizer regularizer = 2;
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.regularizer_);
    }

    // optional .object_detection.protos.Initializer initializer = 3;
    if (cached_has_bits & 0x00000002u) {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.initializer_);
    }

    // optional bool regularize_depthwise = 6 [default = false];
    if (cached_has_bits & 0x00000004u) {
      total_size += 1 + 1;
    }

    // optional .object_detection.protos.Hyperparams.Op op = 1 [default = CONV];
    if (cached_has_bits & 0x00000008u) {
      total_size += 1 +
        ::_pbi::WireFormatLite::EnumSize(this->_internal_op());
    }

    // optional .object_detection.protos.Hyperparams.Activation activation = 4 [default = RELU];
    if (cached_has_bits & 0x00000010u) {
      total_size += 1 +
        ::_pbi::WireFormatLite::EnumSize(this->_internal_activation());
    }

  }
  switch (normalizer_oneof_case()) {
    // .object_detection.protos.BatchNorm batch_norm = 5;
    case kBatchNorm: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.normalizer_oneof_.batch_norm_);
      break;
    }
    // .object_detection.protos.GroupNorm group_norm = 7;
    case kGroupNorm: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.normalizer_oneof_.group_norm_);
      break;
    }
    case NORMALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData Hyperparams::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    Hyperparams::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*Hyperparams::GetClassData() const { return &_class_data_; }


void Hyperparams::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<Hyperparams*>(&to_msg);
  auto& from = static_cast<const Hyperparams&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.Hyperparams)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x0000001fu) {
    if (cached_has_bits & 0x00000001u) {
      _this->_internal_mutable_regularizer()->::object_detection::protos::Regularizer::MergeFrom(
          from._internal_regularizer());
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_internal_mutable_initializer()->::object_detection::protos::Initializer::MergeFrom(
          from._internal_initializer());
    }
    if (cached_has_bits & 0x00000004u) {
      _this->_impl_.regularize_depthwise_ = from._impl_.regularize_depthwise_;
    }
    if (cached_has_bits & 0x00000008u) {
      _this->_impl_.op_ = from._impl_.op_;
    }
    if (cached_has_bits & 0x00000010u) {
      _this->_impl_.activation_ = from._impl_.activation_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  switch (from.normalizer_oneof_case()) {
    case kBatchNorm: {
      _this->_internal_mutable_batch_norm()->::object_detection::protos::BatchNorm::MergeFrom(
          from._internal_batch_norm());
      break;
    }
    case kGroupNorm: {
      _this->_internal_mutable_group_norm()->::object_detection::protos::GroupNorm::MergeFrom(
          from._internal_group_norm());
      break;
    }
    case NORMALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void Hyperparams::CopyFrom(const Hyperparams& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.Hyperparams)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool Hyperparams::IsInitialized() const {
  return true;
}

void Hyperparams::InternalSwap(Hyperparams* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::PROTOBUF_NAMESPACE_ID::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Hyperparams, _impl_.regularize_depthwise_)
      + sizeof(Hyperparams::_impl_.regularize_depthwise_)
      - PROTOBUF_FIELD_OFFSET(Hyperparams, _impl_.regularizer_)>(
          reinterpret_cast<char*>(&_impl_.regularizer_),
          reinterpret_cast<char*>(&other->_impl_.regularizer_));
  swap(_impl_.op_, other->_impl_.op_);
  swap(_impl_.activation_, other->_impl_.activation_);
  swap(_impl_.normalizer_oneof_, other->_impl_.normalizer_oneof_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::PROTOBUF_NAMESPACE_ID::Metadata Hyperparams::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[0]);
}

// ===================================================================

class Regularizer::_Internal {
 public:
  static const ::object_detection::protos::L1Regularizer& l1_regularizer(const Regularizer* msg);
  static const ::object_detection::protos::L2Regularizer& l2_regularizer(const Regularizer* msg);
};

const ::object_detection::protos::L1Regularizer&
Regularizer::_Internal::l1_regularizer(const Regularizer* msg) {
  return *msg->_impl_.regularizer_oneof_.l1_regularizer_;
}
const ::object_detection::protos::L2Regularizer&
Regularizer::_Internal::l2_regularizer(const Regularizer* msg) {
  return *msg->_impl_.regularizer_oneof_.l2_regularizer_;
}
void Regularizer::set_allocated_l1_regularizer(::object_detection::protos::L1Regularizer* l1_regularizer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_regularizer_oneof();
  if (l1_regularizer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(l1_regularizer);
    if (message_arena != submessage_arena) {
      l1_regularizer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, l1_regularizer, submessage_arena);
    }
    set_has_l1_regularizer();
    _impl_.regularizer_oneof_.l1_regularizer_ = l1_regularizer;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Regularizer.l1_regularizer)
}
void Regularizer::set_allocated_l2_regularizer(::object_detection::protos::L2Regularizer* l2_regularizer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_regularizer_oneof();
  if (l2_regularizer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(l2_regularizer);
    if (message_arena != submessage_arena) {
      l2_regularizer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, l2_regularizer, submessage_arena);
    }
    set_has_l2_regularizer();
    _impl_.regularizer_oneof_.l2_regularizer_ = l2_regularizer;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Regularizer.l2_regularizer)
}
Regularizer::Regularizer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.Regularizer)
}
Regularizer::Regularizer(const Regularizer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  Regularizer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_.regularizer_oneof_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , /*decltype(_impl_._oneof_case_)*/{}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  clear_has_regularizer_oneof();
  switch (from.regularizer_oneof_case()) {
    case kL1Regularizer: {
      _this->_internal_mutable_l1_regularizer()->::object_detection::protos::L1Regularizer::MergeFrom(
          from._internal_l1_regularizer());
      break;
    }
    case kL2Regularizer: {
      _this->_internal_mutable_l2_regularizer()->::object_detection::protos::L2Regularizer::MergeFrom(
          from._internal_l2_regularizer());
      break;
    }
    case REGULARIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.Regularizer)
}

inline void Regularizer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_.regularizer_oneof_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , /*decltype(_impl_._oneof_case_)*/{}
  };
  clear_has_regularizer_oneof();
}

Regularizer::~Regularizer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.Regularizer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void Regularizer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
  if (has_regularizer_oneof()) {
    clear_regularizer_oneof();
  }
}

void Regularizer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void Regularizer::clear_regularizer_oneof() {
// @@protoc_insertion_point(one_of_clear_start:object_detection.protos.Regularizer)
  switch (regularizer_oneof_case()) {
    case kL1Regularizer: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.regularizer_oneof_.l1_regularizer_;
      }
      break;
    }
    case kL2Regularizer: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.regularizer_oneof_.l2_regularizer_;
      }
      break;
    }
    case REGULARIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = REGULARIZER_ONEOF_NOT_SET;
}


void Regularizer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.Regularizer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  clear_regularizer_oneof();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* Regularizer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // .object_detection.protos.L1Regularizer l1_regularizer = 1;
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 10)) {
          ptr = ctx->ParseMessage(_internal_mutable_l1_regularizer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // .object_detection.protos.L2Regularizer l2_regularizer = 2;
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 18)) {
          ptr = ctx->ParseMessage(_internal_mutable_l2_regularizer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* Regularizer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.Regularizer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  switch (regularizer_oneof_case()) {
    case kL1Regularizer: {
      target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
        InternalWriteMessage(1, _Internal::l1_regularizer(this),
          _Internal::l1_regularizer(this).GetCachedSize(), target, stream);
      break;
    }
    case kL2Regularizer: {
      target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
        InternalWriteMessage(2, _Internal::l2_regularizer(this),
          _Internal::l2_regularizer(this).GetCachedSize(), target, stream);
      break;
    }
    default: ;
  }
  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.Regularizer)
  return target;
}

size_t Regularizer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.Regularizer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  switch (regularizer_oneof_case()) {
    // .object_detection.protos.L1Regularizer l1_regularizer = 1;
    case kL1Regularizer: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.regularizer_oneof_.l1_regularizer_);
      break;
    }
    // .object_detection.protos.L2Regularizer l2_regularizer = 2;
    case kL2Regularizer: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.regularizer_oneof_.l2_regularizer_);
      break;
    }
    case REGULARIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData Regularizer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    Regularizer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*Regularizer::GetClassData() const { return &_class_data_; }


void Regularizer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<Regularizer*>(&to_msg);
  auto& from = static_cast<const Regularizer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.Regularizer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  switch (from.regularizer_oneof_case()) {
    case kL1Regularizer: {
      _this->_internal_mutable_l1_regularizer()->::object_detection::protos::L1Regularizer::MergeFrom(
          from._internal_l1_regularizer());
      break;
    }
    case kL2Regularizer: {
      _this->_internal_mutable_l2_regularizer()->::object_detection::protos::L2Regularizer::MergeFrom(
          from._internal_l2_regularizer());
      break;
    }
    case REGULARIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void Regularizer::CopyFrom(const Regularizer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.Regularizer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool Regularizer::IsInitialized() const {
  return true;
}

void Regularizer::InternalSwap(Regularizer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_.regularizer_oneof_, other->_impl_.regularizer_oneof_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::PROTOBUF_NAMESPACE_ID::Metadata Regularizer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[1]);
}

// ===================================================================

class L1Regularizer::_Internal {
 public:
  using HasBits = decltype(std::declval<L1Regularizer>()._impl_._has_bits_);
  static void set_has_weight(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
};

L1Regularizer::L1Regularizer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.L1Regularizer)
}
L1Regularizer::L1Regularizer(const L1Regularizer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  L1Regularizer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.weight_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  _this->_impl_.weight_ = from._impl_.weight_;
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.L1Regularizer)
}

inline void L1Regularizer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.weight_){1}
  };
}

L1Regularizer::~L1Regularizer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.L1Regularizer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void L1Regularizer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void L1Regularizer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void L1Regularizer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.L1Regularizer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.weight_ = 1;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* L1Regularizer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float weight = 1 [default = 1];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_weight(&has_bits);
          _impl_.weight_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* L1Regularizer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.L1Regularizer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float weight = 1 [default = 1];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_weight(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.L1Regularizer)
  return target;
}

size_t L1Regularizer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.L1Regularizer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  // optional float weight = 1 [default = 1];
  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000001u) {
    total_size += 1 + 4;
  }

  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData L1Regularizer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    L1Regularizer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*L1Regularizer::GetClassData() const { return &_class_data_; }


void L1Regularizer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<L1Regularizer*>(&to_msg);
  auto& from = static_cast<const L1Regularizer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.L1Regularizer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  if (from._internal_has_weight()) {
    _this->_internal_set_weight(from._internal_weight());
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void L1Regularizer::CopyFrom(const L1Regularizer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.L1Regularizer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool L1Regularizer::IsInitialized() const {
  return true;
}

void L1Regularizer::InternalSwap(L1Regularizer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.weight_, other->_impl_.weight_);
}

::PROTOBUF_NAMESPACE_ID::Metadata L1Regularizer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[2]);
}

// ===================================================================

class L2Regularizer::_Internal {
 public:
  using HasBits = decltype(std::declval<L2Regularizer>()._impl_._has_bits_);
  static void set_has_weight(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
};

L2Regularizer::L2Regularizer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.L2Regularizer)
}
L2Regularizer::L2Regularizer(const L2Regularizer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  L2Regularizer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.weight_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  _this->_impl_.weight_ = from._impl_.weight_;
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.L2Regularizer)
}

inline void L2Regularizer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.weight_){1}
  };
}

L2Regularizer::~L2Regularizer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.L2Regularizer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void L2Regularizer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void L2Regularizer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void L2Regularizer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.L2Regularizer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.weight_ = 1;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* L2Regularizer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float weight = 1 [default = 1];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_weight(&has_bits);
          _impl_.weight_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* L2Regularizer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.L2Regularizer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float weight = 1 [default = 1];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_weight(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.L2Regularizer)
  return target;
}

size_t L2Regularizer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.L2Regularizer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  // optional float weight = 1 [default = 1];
  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000001u) {
    total_size += 1 + 4;
  }

  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData L2Regularizer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    L2Regularizer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*L2Regularizer::GetClassData() const { return &_class_data_; }


void L2Regularizer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<L2Regularizer*>(&to_msg);
  auto& from = static_cast<const L2Regularizer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.L2Regularizer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  if (from._internal_has_weight()) {
    _this->_internal_set_weight(from._internal_weight());
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void L2Regularizer::CopyFrom(const L2Regularizer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.L2Regularizer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool L2Regularizer::IsInitialized() const {
  return true;
}

void L2Regularizer::InternalSwap(L2Regularizer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.weight_, other->_impl_.weight_);
}

::PROTOBUF_NAMESPACE_ID::Metadata L2Regularizer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[3]);
}

// ===================================================================

class Initializer::_Internal {
 public:
  static const ::object_detection::protos::TruncatedNormalInitializer& truncated_normal_initializer(const Initializer* msg);
  static const ::object_detection::protos::VarianceScalingInitializer& variance_scaling_initializer(const Initializer* msg);
  static const ::object_detection::protos::RandomNormalInitializer& random_normal_initializer(const Initializer* msg);
};

const ::object_detection::protos::TruncatedNormalInitializer&
Initializer::_Internal::truncated_normal_initializer(const Initializer* msg) {
  return *msg->_impl_.initializer_oneof_.truncated_normal_initializer_;
}
const ::object_detection::protos::VarianceScalingInitializer&
Initializer::_Internal::variance_scaling_initializer(const Initializer* msg) {
  return *msg->_impl_.initializer_oneof_.variance_scaling_initializer_;
}
const ::object_detection::protos::RandomNormalInitializer&
Initializer::_Internal::random_normal_initializer(const Initializer* msg) {
  return *msg->_impl_.initializer_oneof_.random_normal_initializer_;
}
void Initializer::set_allocated_truncated_normal_initializer(::object_detection::protos::TruncatedNormalInitializer* truncated_normal_initializer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_initializer_oneof();
  if (truncated_normal_initializer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(truncated_normal_initializer);
    if (message_arena != submessage_arena) {
      truncated_normal_initializer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, truncated_normal_initializer, submessage_arena);
    }
    set_has_truncated_normal_initializer();
    _impl_.initializer_oneof_.truncated_normal_initializer_ = truncated_normal_initializer;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Initializer.truncated_normal_initializer)
}
void Initializer::set_allocated_variance_scaling_initializer(::object_detection::protos::VarianceScalingInitializer* variance_scaling_initializer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_initializer_oneof();
  if (variance_scaling_initializer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(variance_scaling_initializer);
    if (message_arena != submessage_arena) {
      variance_scaling_initializer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, variance_scaling_initializer, submessage_arena);
    }
    set_has_variance_scaling_initializer();
    _impl_.initializer_oneof_.variance_scaling_initializer_ = variance_scaling_initializer;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Initializer.variance_scaling_initializer)
}
void Initializer::set_allocated_random_normal_initializer(::object_detection::protos::RandomNormalInitializer* random_normal_initializer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  clear_initializer_oneof();
  if (random_normal_initializer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(random_normal_initializer);
    if (message_arena != submessage_arena) {
      random_normal_initializer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, random_normal_initializer, submessage_arena);
    }
    set_has_random_normal_initializer();
    _impl_.initializer_oneof_.random_normal_initializer_ = random_normal_initializer;
  }
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.Initializer.random_normal_initializer)
}
Initializer::Initializer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.Initializer)
}
Initializer::Initializer(const Initializer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  Initializer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_.initializer_oneof_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , /*decltype(_impl_._oneof_case_)*/{}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  clear_has_initializer_oneof();
  switch (from.initializer_oneof_case()) {
    case kTruncatedNormalInitializer: {
      _this->_internal_mutable_truncated_normal_initializer()->::object_detection::protos::TruncatedNormalInitializer::MergeFrom(
          from._internal_truncated_normal_initializer());
      break;
    }
    case kVarianceScalingInitializer: {
      _this->_internal_mutable_variance_scaling_initializer()->::object_detection::protos::VarianceScalingInitializer::MergeFrom(
          from._internal_variance_scaling_initializer());
      break;
    }
    case kRandomNormalInitializer: {
      _this->_internal_mutable_random_normal_initializer()->::object_detection::protos::RandomNormalInitializer::MergeFrom(
          from._internal_random_normal_initializer());
      break;
    }
    case INITIALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.Initializer)
}

inline void Initializer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_.initializer_oneof_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , /*decltype(_impl_._oneof_case_)*/{}
  };
  clear_has_initializer_oneof();
}

Initializer::~Initializer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.Initializer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void Initializer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
  if (has_initializer_oneof()) {
    clear_initializer_oneof();
  }
}

void Initializer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void Initializer::clear_initializer_oneof() {
// @@protoc_insertion_point(one_of_clear_start:object_detection.protos.Initializer)
  switch (initializer_oneof_case()) {
    case kTruncatedNormalInitializer: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.initializer_oneof_.truncated_normal_initializer_;
      }
      break;
    }
    case kVarianceScalingInitializer: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.initializer_oneof_.variance_scaling_initializer_;
      }
      break;
    }
    case kRandomNormalInitializer: {
      if (GetArenaForAllocation() == nullptr) {
        delete _impl_.initializer_oneof_.random_normal_initializer_;
      }
      break;
    }
    case INITIALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = INITIALIZER_ONEOF_NOT_SET;
}


void Initializer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.Initializer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  clear_initializer_oneof();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* Initializer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // .object_detection.protos.TruncatedNormalInitializer truncated_normal_initializer = 1;
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 10)) {
          ptr = ctx->ParseMessage(_internal_mutable_truncated_normal_initializer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // .object_detection.protos.VarianceScalingInitializer variance_scaling_initializer = 2;
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 18)) {
          ptr = ctx->ParseMessage(_internal_mutable_variance_scaling_initializer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // .object_detection.protos.RandomNormalInitializer random_normal_initializer = 3;
      case 3:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 26)) {
          ptr = ctx->ParseMessage(_internal_mutable_random_normal_initializer(), ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* Initializer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.Initializer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  switch (initializer_oneof_case()) {
    case kTruncatedNormalInitializer: {
      target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
        InternalWriteMessage(1, _Internal::truncated_normal_initializer(this),
          _Internal::truncated_normal_initializer(this).GetCachedSize(), target, stream);
      break;
    }
    case kVarianceScalingInitializer: {
      target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
        InternalWriteMessage(2, _Internal::variance_scaling_initializer(this),
          _Internal::variance_scaling_initializer(this).GetCachedSize(), target, stream);
      break;
    }
    case kRandomNormalInitializer: {
      target = ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::
        InternalWriteMessage(3, _Internal::random_normal_initializer(this),
          _Internal::random_normal_initializer(this).GetCachedSize(), target, stream);
      break;
    }
    default: ;
  }
  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.Initializer)
  return target;
}

size_t Initializer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.Initializer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  switch (initializer_oneof_case()) {
    // .object_detection.protos.TruncatedNormalInitializer truncated_normal_initializer = 1;
    case kTruncatedNormalInitializer: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.initializer_oneof_.truncated_normal_initializer_);
      break;
    }
    // .object_detection.protos.VarianceScalingInitializer variance_scaling_initializer = 2;
    case kVarianceScalingInitializer: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.initializer_oneof_.variance_scaling_initializer_);
      break;
    }
    // .object_detection.protos.RandomNormalInitializer random_normal_initializer = 3;
    case kRandomNormalInitializer: {
      total_size += 1 +
        ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::MessageSize(
          *_impl_.initializer_oneof_.random_normal_initializer_);
      break;
    }
    case INITIALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData Initializer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    Initializer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*Initializer::GetClassData() const { return &_class_data_; }


void Initializer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<Initializer*>(&to_msg);
  auto& from = static_cast<const Initializer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.Initializer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  switch (from.initializer_oneof_case()) {
    case kTruncatedNormalInitializer: {
      _this->_internal_mutable_truncated_normal_initializer()->::object_detection::protos::TruncatedNormalInitializer::MergeFrom(
          from._internal_truncated_normal_initializer());
      break;
    }
    case kVarianceScalingInitializer: {
      _this->_internal_mutable_variance_scaling_initializer()->::object_detection::protos::VarianceScalingInitializer::MergeFrom(
          from._internal_variance_scaling_initializer());
      break;
    }
    case kRandomNormalInitializer: {
      _this->_internal_mutable_random_normal_initializer()->::object_detection::protos::RandomNormalInitializer::MergeFrom(
          from._internal_random_normal_initializer());
      break;
    }
    case INITIALIZER_ONEOF_NOT_SET: {
      break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void Initializer::CopyFrom(const Initializer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.Initializer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool Initializer::IsInitialized() const {
  return true;
}

void Initializer::InternalSwap(Initializer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_.initializer_oneof_, other->_impl_.initializer_oneof_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::PROTOBUF_NAMESPACE_ID::Metadata Initializer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[4]);
}

// ===================================================================

class TruncatedNormalInitializer::_Internal {
 public:
  using HasBits = decltype(std::declval<TruncatedNormalInitializer>()._impl_._has_bits_);
  static void set_has_mean(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
  static void set_has_stddev(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
};

TruncatedNormalInitializer::TruncatedNormalInitializer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.TruncatedNormalInitializer)
}
TruncatedNormalInitializer::TruncatedNormalInitializer(const TruncatedNormalInitializer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  TruncatedNormalInitializer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.mean_){}
    , decltype(_impl_.stddev_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  ::memcpy(&_impl_.mean_, &from._impl_.mean_,
    static_cast<size_t>(reinterpret_cast<char*>(&_impl_.stddev_) -
    reinterpret_cast<char*>(&_impl_.mean_)) + sizeof(_impl_.stddev_));
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.TruncatedNormalInitializer)
}

inline void TruncatedNormalInitializer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.mean_){0}
    , decltype(_impl_.stddev_){1}
  };
}

TruncatedNormalInitializer::~TruncatedNormalInitializer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.TruncatedNormalInitializer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void TruncatedNormalInitializer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void TruncatedNormalInitializer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void TruncatedNormalInitializer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.TruncatedNormalInitializer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    _impl_.mean_ = 0;
    _impl_.stddev_ = 1;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* TruncatedNormalInitializer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float mean = 1 [default = 0];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_mean(&has_bits);
          _impl_.mean_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      // optional float stddev = 2 [default = 1];
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 21)) {
          _Internal::set_has_stddev(&has_bits);
          _impl_.stddev_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* TruncatedNormalInitializer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.TruncatedNormalInitializer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float mean = 1 [default = 0];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_mean(), target);
  }

  // optional float stddev = 2 [default = 1];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(2, this->_internal_stddev(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.TruncatedNormalInitializer)
  return target;
}

size_t TruncatedNormalInitializer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.TruncatedNormalInitializer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    // optional float mean = 1 [default = 0];
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + 4;
    }

    // optional float stddev = 2 [default = 1];
    if (cached_has_bits & 0x00000002u) {
      total_size += 1 + 4;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData TruncatedNormalInitializer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    TruncatedNormalInitializer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*TruncatedNormalInitializer::GetClassData() const { return &_class_data_; }


void TruncatedNormalInitializer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<TruncatedNormalInitializer*>(&to_msg);
  auto& from = static_cast<const TruncatedNormalInitializer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.TruncatedNormalInitializer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    if (cached_has_bits & 0x00000001u) {
      _this->_impl_.mean_ = from._impl_.mean_;
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.stddev_ = from._impl_.stddev_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void TruncatedNormalInitializer::CopyFrom(const TruncatedNormalInitializer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.TruncatedNormalInitializer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool TruncatedNormalInitializer::IsInitialized() const {
  return true;
}

void TruncatedNormalInitializer::InternalSwap(TruncatedNormalInitializer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.mean_, other->_impl_.mean_);
  swap(_impl_.stddev_, other->_impl_.stddev_);
}

::PROTOBUF_NAMESPACE_ID::Metadata TruncatedNormalInitializer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[5]);
}

// ===================================================================

class VarianceScalingInitializer::_Internal {
 public:
  using HasBits = decltype(std::declval<VarianceScalingInitializer>()._impl_._has_bits_);
  static void set_has_factor(HasBits* has_bits) {
    (*has_bits)[0] |= 4u;
  }
  static void set_has_uniform(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
  static void set_has_mode(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
};

VarianceScalingInitializer::VarianceScalingInitializer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.VarianceScalingInitializer)
}
VarianceScalingInitializer::VarianceScalingInitializer(const VarianceScalingInitializer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  VarianceScalingInitializer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.uniform_){}
    , decltype(_impl_.mode_){}
    , decltype(_impl_.factor_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  ::memcpy(&_impl_.uniform_, &from._impl_.uniform_,
    static_cast<size_t>(reinterpret_cast<char*>(&_impl_.factor_) -
    reinterpret_cast<char*>(&_impl_.uniform_)) + sizeof(_impl_.factor_));
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.VarianceScalingInitializer)
}

inline void VarianceScalingInitializer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.uniform_){false}
    , decltype(_impl_.mode_){0}
    , decltype(_impl_.factor_){2}
  };
}

VarianceScalingInitializer::~VarianceScalingInitializer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.VarianceScalingInitializer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void VarianceScalingInitializer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void VarianceScalingInitializer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void VarianceScalingInitializer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.VarianceScalingInitializer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000007u) {
    ::memset(&_impl_.uniform_, 0, static_cast<size_t>(
        reinterpret_cast<char*>(&_impl_.mode_) -
        reinterpret_cast<char*>(&_impl_.uniform_)) + sizeof(_impl_.mode_));
    _impl_.factor_ = 2;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* VarianceScalingInitializer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float factor = 1 [default = 2];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_factor(&has_bits);
          _impl_.factor_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      // optional bool uniform = 2 [default = false];
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 16)) {
          _Internal::set_has_uniform(&has_bits);
          _impl_.uniform_ = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional .object_detection.protos.VarianceScalingInitializer.Mode mode = 3 [default = FAN_IN];
      case 3:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 24)) {
          uint64_t val = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
          if (PROTOBUF_PREDICT_TRUE(::object_detection::protos::VarianceScalingInitializer_Mode_IsValid(val))) {
            _internal_set_mode(static_cast<::object_detection::protos::VarianceScalingInitializer_Mode>(val));
          } else {
            ::PROTOBUF_NAMESPACE_ID::internal::WriteVarint(3, val, mutable_unknown_fields());
          }
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* VarianceScalingInitializer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.VarianceScalingInitializer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float factor = 1 [default = 2];
  if (cached_has_bits & 0x00000004u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_factor(), target);
  }

  // optional bool uniform = 2 [default = false];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(2, this->_internal_uniform(), target);
  }

  // optional .object_detection.protos.VarianceScalingInitializer.Mode mode = 3 [default = FAN_IN];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteEnumToArray(
      3, this->_internal_mode(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.VarianceScalingInitializer)
  return target;
}

size_t VarianceScalingInitializer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.VarianceScalingInitializer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000007u) {
    // optional bool uniform = 2 [default = false];
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + 1;
    }

    // optional .object_detection.protos.VarianceScalingInitializer.Mode mode = 3 [default = FAN_IN];
    if (cached_has_bits & 0x00000002u) {
      total_size += 1 +
        ::_pbi::WireFormatLite::EnumSize(this->_internal_mode());
    }

    // optional float factor = 1 [default = 2];
    if (cached_has_bits & 0x00000004u) {
      total_size += 1 + 4;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData VarianceScalingInitializer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    VarianceScalingInitializer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*VarianceScalingInitializer::GetClassData() const { return &_class_data_; }


void VarianceScalingInitializer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<VarianceScalingInitializer*>(&to_msg);
  auto& from = static_cast<const VarianceScalingInitializer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.VarianceScalingInitializer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x00000007u) {
    if (cached_has_bits & 0x00000001u) {
      _this->_impl_.uniform_ = from._impl_.uniform_;
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.mode_ = from._impl_.mode_;
    }
    if (cached_has_bits & 0x00000004u) {
      _this->_impl_.factor_ = from._impl_.factor_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void VarianceScalingInitializer::CopyFrom(const VarianceScalingInitializer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.VarianceScalingInitializer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool VarianceScalingInitializer::IsInitialized() const {
  return true;
}

void VarianceScalingInitializer::InternalSwap(VarianceScalingInitializer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::PROTOBUF_NAMESPACE_ID::internal::memswap<
      PROTOBUF_FIELD_OFFSET(VarianceScalingInitializer, _impl_.mode_)
      + sizeof(VarianceScalingInitializer::_impl_.mode_)
      - PROTOBUF_FIELD_OFFSET(VarianceScalingInitializer, _impl_.uniform_)>(
          reinterpret_cast<char*>(&_impl_.uniform_),
          reinterpret_cast<char*>(&other->_impl_.uniform_));
  swap(_impl_.factor_, other->_impl_.factor_);
}

::PROTOBUF_NAMESPACE_ID::Metadata VarianceScalingInitializer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[6]);
}

// ===================================================================

class RandomNormalInitializer::_Internal {
 public:
  using HasBits = decltype(std::declval<RandomNormalInitializer>()._impl_._has_bits_);
  static void set_has_mean(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
  static void set_has_stddev(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
};

RandomNormalInitializer::RandomNormalInitializer(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.RandomNormalInitializer)
}
RandomNormalInitializer::RandomNormalInitializer(const RandomNormalInitializer& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  RandomNormalInitializer* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.mean_){}
    , decltype(_impl_.stddev_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  ::memcpy(&_impl_.mean_, &from._impl_.mean_,
    static_cast<size_t>(reinterpret_cast<char*>(&_impl_.stddev_) -
    reinterpret_cast<char*>(&_impl_.mean_)) + sizeof(_impl_.stddev_));
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.RandomNormalInitializer)
}

inline void RandomNormalInitializer::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.mean_){0}
    , decltype(_impl_.stddev_){1}
  };
}

RandomNormalInitializer::~RandomNormalInitializer() {
  // @@protoc_insertion_point(destructor:object_detection.protos.RandomNormalInitializer)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void RandomNormalInitializer::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void RandomNormalInitializer::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void RandomNormalInitializer::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.RandomNormalInitializer)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    _impl_.mean_ = 0;
    _impl_.stddev_ = 1;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* RandomNormalInitializer::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float mean = 1 [default = 0];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_mean(&has_bits);
          _impl_.mean_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      // optional float stddev = 2 [default = 1];
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 21)) {
          _Internal::set_has_stddev(&has_bits);
          _impl_.stddev_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* RandomNormalInitializer::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.RandomNormalInitializer)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float mean = 1 [default = 0];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_mean(), target);
  }

  // optional float stddev = 2 [default = 1];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(2, this->_internal_stddev(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.RandomNormalInitializer)
  return target;
}

size_t RandomNormalInitializer::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.RandomNormalInitializer)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    // optional float mean = 1 [default = 0];
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + 4;
    }

    // optional float stddev = 2 [default = 1];
    if (cached_has_bits & 0x00000002u) {
      total_size += 1 + 4;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData RandomNormalInitializer::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    RandomNormalInitializer::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*RandomNormalInitializer::GetClassData() const { return &_class_data_; }


void RandomNormalInitializer::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<RandomNormalInitializer*>(&to_msg);
  auto& from = static_cast<const RandomNormalInitializer&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.RandomNormalInitializer)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x00000003u) {
    if (cached_has_bits & 0x00000001u) {
      _this->_impl_.mean_ = from._impl_.mean_;
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.stddev_ = from._impl_.stddev_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void RandomNormalInitializer::CopyFrom(const RandomNormalInitializer& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.RandomNormalInitializer)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool RandomNormalInitializer::IsInitialized() const {
  return true;
}

void RandomNormalInitializer::InternalSwap(RandomNormalInitializer* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.mean_, other->_impl_.mean_);
  swap(_impl_.stddev_, other->_impl_.stddev_);
}

::PROTOBUF_NAMESPACE_ID::Metadata RandomNormalInitializer::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[7]);
}

// ===================================================================

class BatchNorm::_Internal {
 public:
  using HasBits = decltype(std::declval<BatchNorm>()._impl_._has_bits_);
  static void set_has_decay(HasBits* has_bits) {
    (*has_bits)[0] |= 4u;
  }
  static void set_has_center(HasBits* has_bits) {
    (*has_bits)[0] |= 8u;
  }
  static void set_has_scale(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
  static void set_has_epsilon(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
  static void set_has_train(HasBits* has_bits) {
    (*has_bits)[0] |= 16u;
  }
};

BatchNorm::BatchNorm(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::Message(arena, is_message_owned) {
  SharedCtor(arena, is_message_owned);
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.BatchNorm)
}
BatchNorm::BatchNorm(const BatchNorm& from)
  : ::PROTOBUF_NAMESPACE_ID::Message() {
  BatchNorm* const _this = this; (void)_this;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){from._impl_._has_bits_}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.scale_){}
    , decltype(_impl_.epsilon_){}
    , decltype(_impl_.decay_){}
    , decltype(_impl_.center_){}
    , decltype(_impl_.train_){}};

  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  ::memcpy(&_impl_.scale_, &from._impl_.scale_,
    static_cast<size_t>(reinterpret_cast<char*>(&_impl_.train_) -
    reinterpret_cast<char*>(&_impl_.scale_)) + sizeof(_impl_.train_));
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.BatchNorm)
}

inline void BatchNorm::SharedCtor(
    ::_pb::Arena* arena, bool is_message_owned) {
  (void)arena;
  (void)is_message_owned;
  new (&_impl_) Impl_{
      decltype(_impl_._has_bits_){}
    , /*decltype(_impl_._cached_size_)*/{}
    , decltype(_impl_.scale_){false}
    , decltype(_impl_.epsilon_){0.001f}
    , decltype(_impl_.decay_){0.999f}
    , decltype(_impl_.center_){true}
    , decltype(_impl_.train_){true}
  };
}

BatchNorm::~BatchNorm() {
  // @@protoc_insertion_point(destructor:object_detection.protos.BatchNorm)
  if (auto *arena = _internal_metadata_.DeleteReturnArena<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>()) {
  (void)arena;
    return;
  }
  SharedDtor();
}

inline void BatchNorm::SharedDtor() {
  GOOGLE_DCHECK(GetArenaForAllocation() == nullptr);
}

void BatchNorm::SetCachedSize(int size) const {
  _impl_._cached_size_.Set(size);
}

void BatchNorm::Clear() {
// @@protoc_insertion_point(message_clear_start:object_detection.protos.BatchNorm)
  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x0000001fu) {
    _impl_.scale_ = false;
    _impl_.epsilon_ = 0.001f;
    _impl_.decay_ = 0.999f;
    _impl_.center_ = true;
    _impl_.train_ = true;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
}

const char* BatchNorm::_InternalParse(const char* ptr, ::_pbi::ParseContext* ctx) {
#define CHK_(x) if (PROTOBUF_PREDICT_FALSE(!(x))) goto failure
  _Internal::HasBits has_bits{};
  while (!ctx->Done(&ptr)) {
    uint32_t tag;
    ptr = ::_pbi::ReadTag(ptr, &tag);
    switch (tag >> 3) {
      // optional float decay = 1 [default = 0.999];
      case 1:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 13)) {
          _Internal::set_has_decay(&has_bits);
          _impl_.decay_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      // optional bool center = 2 [default = true];
      case 2:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 16)) {
          _Internal::set_has_center(&has_bits);
          _impl_.center_ = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional bool scale = 3 [default = false];
      case 3:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 24)) {
          _Internal::set_has_scale(&has_bits);
          _impl_.scale_ = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      // optional float epsilon = 4 [default = 0.001];
      case 4:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 37)) {
          _Internal::set_has_epsilon(&has_bits);
          _impl_.epsilon_ = ::PROTOBUF_NAMESPACE_ID::internal::UnalignedLoad<float>(ptr);
          ptr += sizeof(float);
        } else
          goto handle_unusual;
        continue;
      // optional bool train = 5 [default = true];
      case 5:
        if (PROTOBUF_PREDICT_TRUE(static_cast<uint8_t>(tag) == 40)) {
          _Internal::set_has_train(&has_bits);
          _impl_.train_ = ::PROTOBUF_NAMESPACE_ID::internal::ReadVarint64(&ptr);
          CHK_(ptr);
        } else
          goto handle_unusual;
        continue;
      default:
        goto handle_unusual;
    }  // switch
  handle_unusual:
    if ((tag == 0) || ((tag & 7) == 4)) {
      CHK_(ptr);
      ctx->SetLastTag(tag);
      goto message_done;
    }
    ptr = UnknownFieldParse(
        tag,
        _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(),
        ptr, ctx);
    CHK_(ptr != nullptr);
  }  // while
message_done:
  _impl_._has_bits_.Or(has_bits);
  return ptr;
failure:
  ptr = nullptr;
  goto message_done;
#undef CHK_
}

uint8_t* BatchNorm::_InternalSerialize(
    uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:object_detection.protos.BatchNorm)
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional float decay = 1 [default = 0.999];
  if (cached_has_bits & 0x00000004u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(1, this->_internal_decay(), target);
  }

  // optional bool center = 2 [default = true];
  if (cached_has_bits & 0x00000008u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(2, this->_internal_center(), target);
  }

  // optional bool scale = 3 [default = false];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(3, this->_internal_scale(), target);
  }

  // optional float epsilon = 4 [default = 0.001];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteFloatToArray(4, this->_internal_epsilon(), target);
  }

  // optional bool train = 5 [default = true];
  if (cached_has_bits & 0x00000010u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(5, this->_internal_train(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target = ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
        _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:object_detection.protos.BatchNorm)
  return target;
}

size_t BatchNorm::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:object_detection.protos.BatchNorm)
  size_t total_size = 0;

  uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x0000001fu) {
    // optional bool scale = 3 [default = false];
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + 1;
    }

    // optional float epsilon = 4 [default = 0.001];
    if (cached_has_bits & 0x00000002u) {
      total_size += 1 + 4;
    }

    // optional float decay = 1 [default = 0.999];
    if (cached_has_bits & 0x00000004u) {
      total_size += 1 + 4;
    }

    // optional bool center = 2 [default = true];
    if (cached_has_bits & 0x00000008u) {
      total_size += 1 + 1;
    }

    // optional bool train = 5 [default = true];
    if (cached_has_bits & 0x00000010u) {
      total_size += 1 + 1;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::PROTOBUF_NAMESPACE_ID::Message::ClassData BatchNorm::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::Message::CopyWithSourceCheck,
    BatchNorm::MergeImpl
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*BatchNorm::GetClassData() const { return &_class_data_; }


void BatchNorm::MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg) {
  auto* const _this = static_cast<BatchNorm*>(&to_msg);
  auto& from = static_cast<const BatchNorm&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:object_detection.protos.BatchNorm)
  GOOGLE_DCHECK_NE(&from, _this);
  uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x0000001fu) {
    if (cached_has_bits & 0x00000001u) {
      _this->_impl_.scale_ = from._impl_.scale_;
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.epsilon_ = from._impl_.epsilon_;
    }
    if (cached_has_bits & 0x00000004u) {
      _this->_impl_.decay_ = from._impl_.decay_;
    }
    if (cached_has_bits & 0x00000008u) {
      _this->_impl_.center_ = from._impl_.center_;
    }
    if (cached_has_bits & 0x00000010u) {
      _this->_impl_.train_ = from._impl_.train_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
}

void BatchNorm::CopyFrom(const BatchNorm& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:object_detection.protos.BatchNorm)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool BatchNorm::IsInitialized() const {
  return true;
}

void BatchNorm::InternalSwap(BatchNorm* other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.scale_, other->_impl_.scale_);
  swap(_impl_.epsilon_, other->_impl_.epsilon_);
  swap(_impl_.decay_, other->_impl_.decay_);
  swap(_impl_.center_, other->_impl_.center_);
  swap(_impl_.train_, other->_impl_.train_);
}

::PROTOBUF_NAMESPACE_ID::Metadata BatchNorm::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[8]);
}

// ===================================================================

class GroupNorm::_Internal {
 public:
};

GroupNorm::GroupNorm(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                         bool is_message_owned)
  : ::PROTOBUF_NAMESPACE_ID::internal::ZeroFieldsBase(arena, is_message_owned) {
  // @@protoc_insertion_point(arena_constructor:object_detection.protos.GroupNorm)
}
GroupNorm::GroupNorm(const GroupNorm& from)
  : ::PROTOBUF_NAMESPACE_ID::internal::ZeroFieldsBase() {
  GroupNorm* const _this = this; (void)_this;
  _internal_metadata_.MergeFrom<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(from._internal_metadata_);
  // @@protoc_insertion_point(copy_constructor:object_detection.protos.GroupNorm)
}





const ::PROTOBUF_NAMESPACE_ID::Message::ClassData GroupNorm::_class_data_ = {
    ::PROTOBUF_NAMESPACE_ID::internal::ZeroFieldsBase::CopyImpl,
    ::PROTOBUF_NAMESPACE_ID::internal::ZeroFieldsBase::MergeImpl,
};
const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GroupNorm::GetClassData() const { return &_class_data_; }







::PROTOBUF_NAMESPACE_ID::Metadata GroupNorm::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_getter, &descriptor_table_object_5fdetection_2fprotos_2fhyperparams_2eproto_once,
      file_level_metadata_object_5fdetection_2fprotos_2fhyperparams_2eproto[9]);
}

// @@protoc_insertion_point(namespace_scope)
}  // namespace protos
}  // namespace object_detection
PROTOBUF_NAMESPACE_OPEN
template<> PROTOBUF_NOINLINE ::object_detection::protos::Hyperparams*
Arena::CreateMaybeMessage< ::object_detection::protos::Hyperparams >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::Hyperparams >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::Regularizer*
Arena::CreateMaybeMessage< ::object_detection::protos::Regularizer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::Regularizer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::L1Regularizer*
Arena::CreateMaybeMessage< ::object_detection::protos::L1Regularizer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::L1Regularizer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::L2Regularizer*
Arena::CreateMaybeMessage< ::object_detection::protos::L2Regularizer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::L2Regularizer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::Initializer*
Arena::CreateMaybeMessage< ::object_detection::protos::Initializer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::Initializer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::TruncatedNormalInitializer*
Arena::CreateMaybeMessage< ::object_detection::protos::TruncatedNormalInitializer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::TruncatedNormalInitializer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::VarianceScalingInitializer*
Arena::CreateMaybeMessage< ::object_detection::protos::VarianceScalingInitializer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::VarianceScalingInitializer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::RandomNormalInitializer*
Arena::CreateMaybeMessage< ::object_detection::protos::RandomNormalInitializer >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::RandomNormalInitializer >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::BatchNorm*
Arena::CreateMaybeMessage< ::object_detection::protos::BatchNorm >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::BatchNorm >(arena);
}
template<> PROTOBUF_NOINLINE ::object_detection::protos::GroupNorm*
Arena::CreateMaybeMessage< ::object_detection::protos::GroupNorm >(Arena* arena) {
  return Arena::CreateMessageInternal< ::object_detection::protos::GroupNorm >(arena);
}
PROTOBUF_NAMESPACE_CLOSE

// @@protoc_insertion_point(global_scope)
#include <google/protobuf/port_undef.inc>
